"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidBBAN = exports.isValidIBAN = void 0;
const validIBANSpecifications_1 = require("./validIBANSpecifications");
const isString_1 = require("../../utils/isString");
const NON_ALPHANUM = /[^a-zA-Z0-9]/g;
function electronicFormat(iban) {
    return iban.replace(NON_ALPHANUM, '').toUpperCase();
}
/**
 * Checks whether a given string is a valid International Bank Account Number (IBAN).
 * @param {string} iban The IBAN to validate.
 * @returns `true` if the IBAN is valid, `false` otherwise.
 */
function isValidIBAN(iban) {
    if (!(0, isString_1.isString)(iban)) {
        return false;
    }
    const countryStructure = validIBANSpecifications_1.validIBANSpecifications.get(electronicFormat(iban).slice(0, 2));
    return !!countryStructure && countryStructure.isValidIBAN(iban);
}
exports.isValidIBAN = isValidIBAN;
/**
 * Checks if the provided BBAN (Basic Bank Account Number) is valid for a given country.
 *
 * @param {string} countryCode - The two-letter ISO country code.
 * @param {string} bban - The BBAN to validate.
 * @returns True if the BBAN is valid for the specified country, false otherwise.
 */
function isValidBBAN(countryCode, bban) {
    if (!(0, isString_1.isString)(bban)) {
        return false;
    }
    const countryStructure = validIBANSpecifications_1.validIBANSpecifications.get(countryCode);
    return (!!countryStructure && countryStructure.isValidBBAN(electronicFormat(bban)));
}
exports.isValidBBAN = isValidBBAN;
//# sourceMappingURL=validateBAN.js.map