"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidCVV = void 0;
const CardType_1 = require("../../types/CardType");
/**
 * Validates the CVV code for the given card type.
 * @param {string} cvv - The CVV code to validate.
 * @param {string} cardType - The type of the card (e.g., CardType.Visa, CardType.MasterCard).
 * @returns True if the CVV is valid, false otherwise.
 */
function isValidCVV(cvv, cardType) {
    const cvvRegex = {
        [CardType_1.CardType.Visa]: /^[0-9]{3}$/,
        [CardType_1.CardType.MasterCard]: /^[0-9]{3}$/,
        [CardType_1.CardType.Amex]: /^[0-9]{4}$/,
        [CardType_1.CardType.Discover]: /^[0-9]{3}$/,
        [CardType_1.CardType.JCB]: /^[0-9]{3}$/,
        [CardType_1.CardType.DinersClub]: /^[0-9]{3}$/,
    };
    const regex = cvvRegex[cardType];
    if (!regex) {
        return false;
    }
    return regex.test(cvv.toString());
}
exports.isValidCVV = isValidCVV;
//# sourceMappingURL=validateCVV.js.map