"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidSWIFT = void 0;
const isString_1 = require("../../utils/isString");
/**
 * Checks if the provided SWIFT/BIC code is valid.
 *
 * @param {string} swiftCode - The SWIFT/BIC code to validate.
 * @returns True if the SWIFT/BIC code is valid, false otherwise.
 *
 * @example
 * ```
 * const isValid = isValidSWIFT('DEUTDEFF');
 * console.log(isValid); // true
 *
 * const isValidInvalid = isValidSWIFT('INVALID');
 * console.log(isValidInvalid); // false
 * ```
 */
function isValidSWIFT(swiftCode) {
    if (!(0, isString_1.isString)(swiftCode)) {
        return false;
    }
    const swiftBicRegex = /^[A-Z]{4}[A-Z]{2}[A-Z0-9]{2}([A-Z0-9]{3})?$/;
    return swiftBicRegex.test(swiftCode);
}
exports.isValidSWIFT = isValidSWIFT;
//# sourceMappingURL=validateSwift.js.map